==> mozilla-source-1.3.tar.bz2: mozilla/content/shared/src/nsCSSPseudoElements.cpp <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is atom lists for CSS pseudos.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   L. David Baron <dbaron@dbaron.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#include "nsCSSPseudoElements.h"

// define storage for all atoms
#define CSS_PSEUDO_ELEMENT(_name, _value) \
  nsICSSPseudoElement* nsCSSPseudoElements::_name;
#include "nsCSSPseudoElementList.h"
#undef CSS_PSEUDO_ELEMENT

static nsrefcnt gRefCnt;

void nsCSSPseudoElements::AddRefAtoms()
{
  if (0 == gRefCnt++) {
    // create atoms
#define CSS_PSEUDO_ELEMENT(_name, _value) \
    _name = NS_STATIC_CAST(nsICSSPseudoElement*, NS_NewPermanentAtom(_value));
#include "nsCSSPseudoElementList.h"
#undef CSS_PSEUDO_ELEMENT
  }
}

void nsCSSPseudoElements::ReleaseAtoms()
{
  NS_PRECONDITION(gRefCnt != 0, "bad release atoms");
  if (--gRefCnt == 0) {
    // release atoms
#define CSS_PSEUDO_ELEMENT(_name, _value) NS_RELEASE(_name);
#include "nsCSSPseudoElementList.h"
#undef CSS_PSEUDO_ELEMENT
  }
}

PRBool nsCSSPseudoElements::IsPseudoElement(nsIAtom *aAtom)
{
  return
#define CSS_PSEUDO_ELEMENT(_name, _value) (aAtom == _name) ||
#include "nsCSSPseudoElementList.h"
#undef CSS_PSEUDO_ELEMENT
        PR_FALSE;
}

==> mozilla-source-1.4a.tar.bz2: mozilla/content/shared/src/nsCSSPseudoElements.cpp <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is atom lists for CSS pseudos.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   L. David Baron <dbaron@dbaron.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#include "nsCSSPseudoElements.h"
#include "nsAtomListUtils.h"

// define storage for all atoms
#define CSS_PSEUDO_ELEMENT(_name, _value) \
  nsICSSPseudoElement* nsCSSPseudoElements::_name;
#include "nsCSSPseudoElementList.h"
#undef CSS_PSEUDO_ELEMENT

static nsrefcnt gRefCnt;

static const nsAtomListInfo CSSPseudoElements_info[] = {
#define CSS_PSEUDO_ELEMENT(name_, value_) \
    { (nsIAtom**)&nsCSSPseudoElements::name_, value_ },
#include "nsCSSPseudoElementList.h"
#undef CSS_PSEUDO_ELEMENT
};

void nsCSSPseudoElements::AddRefAtoms()
{
  if (0 == gRefCnt++) {
    nsAtomListUtils::AddRefAtoms(CSSPseudoElements_info,
                                 MOZ_ARRAY_LENGTH(CSSPseudoElements_info));
  }
}

void nsCSSPseudoElements::ReleaseAtoms()
{
  NS_PRECONDITION(gRefCnt != 0, "bad release atoms");
  if (--gRefCnt == 0) {
    nsAtomListUtils::ReleaseAtoms(CSSPseudoElements_info,
                                  MOZ_ARRAY_LENGTH(CSSPseudoElements_info));
  }
}

PRBool nsCSSPseudoElements::IsPseudoElement(nsIAtom *aAtom)
{
  return nsAtomListUtils::IsMember(aAtom, CSSPseudoElements_info,
                                   MOZ_ARRAY_LENGTH(CSSPseudoElements_info));
}
